==> camel-karavan-4.4.0.zip: camel-karavan-4.4.0/karavan-app/src/main/java/org/apache/camel/karavan/model/CamelStatusValue.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.karavan.model;

import java.io.Serial;
import java.io.Serializable;

public class CamelStatusValue implements Serializable {

    @Serial
    private static final long serialVersionUID = 7777777L;

    public enum Name {

        context,
        inflight,
        memory,
        properties,
        route,
        trace,
        jvm,
        source
    }

    Name name;
    String status;

    public CamelStatusValue(Name name, String status) {
        this.name = name;
        this.status = status;
    }

    public Name getName() {
        return name;
    }

    public void setName(Name name) {
        this.name = name;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
}

==> camel-karavan-4.8.0.zip: camel-karavan-4.8.0/karavan-app/src/main/java/org/apache/camel/karavan/model/CamelStatusValue.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.karavan.model;

public class CamelStatusValue {

    public enum Name {

        context,
        inflight,
        memory,
        properties,
        route,
        trace,
        jvm,
        source
    }

    Name name;
    String status;

    public CamelStatusValue() {
    }

    public CamelStatusValue(Name name, String status) {
        this.name = name;
        this.status = status;
    }

    public Name getName() {
        return name;
    }

    public void setName(Name name) {
        this.name = name;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
}
